pub struct MessageEnvelope {
pub id: Uuid,
pub sender: Uuid,
pub recipient: MessageTarget,
pub payload: Payload,
pub timestamp: DateTime<Utc>,
pub ttl: Option<u32>,
pub correlation_id: Option<Uuid>,
}Expand description
A message envelope that wraps any payload with routing metadata.
This is the universal message format used across all transports. Transports serialize/deserialize envelopes to their wire format.
Fields
id: UuidUnique message identifier.
sender: UuidThe sender’s agent identity UUID.
recipient: MessageTargetWho this message is addressed to.
payload: PayloadThe message payload.
timestamp: DateTime<Utc>When the message was created.
ttl: Option<u32>Optional time-to-live (number of hops before the message is dropped).
correlation_id: Option<Uuid>Optional correlation ID for request-response patterns.
Implementations
Sourceimpl MessageEnvelope
impl MessageEnvelope
Sourcepub fn direct(
sender: Uuid,
recipient: Uuid,
payload: impl Into<Payload>,
) -> Self
pub fn direct( sender: Uuid, recipient: Uuid, payload: impl Into<Payload>, ) -> Self
Create a new envelope addressed to a specific agent.
Sourcepub fn broadcast(sender: Uuid, payload: impl Into<Payload>) -> Self
pub fn broadcast(sender: Uuid, payload: impl Into<Payload>) -> Self
Create a new broadcast envelope.
Sourcepub fn topic(
sender: Uuid,
topic: impl Into<String>,
payload: impl Into<Payload>,
) -> Self
pub fn topic( sender: Uuid, topic: impl Into<String>, payload: impl Into<Payload>, ) -> Self
Create a new topic-addressed envelope.
Sourcepub fn with_correlation(self, correlation_id: Uuid) -> Self
pub fn with_correlation(self, correlation_id: Uuid) -> Self
Set a correlation ID for request-response tracking.